=== modified file 'debian/control'
--- debian/control	2014-06-27 08:28:18 +0000
+++ debian/control	2014-06-27 20:48:38 +0000
@@ -13,6 +13,7 @@
                libgles2-mesa-dev[armhf],
                libglib2.0-dev,
                libgsettings-qt-dev,
+               libhardware-dev,
                libhud-client2-dev,
                libpulse-dev,
                libqmenumodel-dev (>= 0.2.7),
@@ -159,6 +160,7 @@
 Multi-Arch: same
 Pre-Depends: ${misc:Pre-Depends},
 Depends: gsettings-ubuntu-schemas,
+         libhardware2,
          libunity-core-6.0-9,
          ${misc:Depends},
          ${shlibs:Depends},

=== modified file 'debian/unity8-private.install'
--- debian/unity8-private.install	2014-06-11 15:36:51 +0000
+++ debian/unity8-private.install	2014-06-27 20:48:38 +0000
@@ -2,6 +2,7 @@
 usr/lib/*/unity8/qml/Dash
 usr/lib/*/unity8/qml/HudClient
 usr/lib/*/unity8/qml/LightDM
+usr/lib/*/unity8/qml/Lights
 usr/lib/*/unity8/qml/Powerd
 usr/lib/*/unity8/qml/SessionBroadcast
 usr/lib/*/unity8/qml/Ubuntu

=== modified file 'plugins/CMakeLists.txt'
--- plugins/CMakeLists.txt	2014-06-11 15:36:51 +0000
+++ plugins/CMakeLists.txt	2014-06-27 20:48:38 +0000
@@ -14,6 +14,7 @@
 add_subdirectory(AccountsService)
 add_subdirectory(HudClient)
 add_subdirectory(LightDM)
+add_subdirectory(Lights)
 add_subdirectory(Dash)
 add_subdirectory(Powerd)
 add_subdirectory(SessionBroadcast)

=== added directory 'plugins/Lights'
=== added file 'plugins/Lights/CMakeLists.txt'
--- plugins/Lights/CMakeLists.txt	1970-01-01 00:00:00 +0000
+++ plugins/Lights/CMakeLists.txt	2014-06-27 20:48:38 +0000
@@ -0,0 +1,18 @@
+include(FindPkgConfig)
+
+pkg_check_modules(ANDROID_HEADERS REQUIRED android-headers)
+pkg_check_modules(ANDROID_HARDWARE REQUIRED libhardware)
+
+include_directories(
+    ${ANDROID_HEADERS_INCLUDE_DIRS}
+)
+
+add_library(Lights-qml MODULE
+    plugin.cpp
+    Lights.cpp
+    )
+
+qt5_use_modules(Lights-qml Qml)
+target_link_libraries(Lights-qml ${ANDROID_HARDWARE_LIBRARIES})
+
+add_unity8_plugin(Lights 0.1 Lights TARGETS Lights-qml)

=== added file 'plugins/Lights/Lights.cpp'
--- plugins/Lights/Lights.cpp	1970-01-01 00:00:00 +0000
+++ plugins/Lights/Lights.cpp	2014-06-27 20:48:38 +0000
@@ -0,0 +1,141 @@
+/*
+ * Copyright (C) 2014 Canonical, Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Author: Renato Araujo Oliveira Filho <renato.filho@canonical.com>
+ */
+
+#include "Lights.h"
+#include <QtCore/QDebug>
+
+extern "C" {
+#include <hardware/hardware.h>
+#include <hardware/lights.h>
+#include <string.h>
+}
+
+Lights::Lights(QObject* parent)
+  : QObject(parent),
+    m_state(Lights::Off),
+    m_lightDevice(0)
+{
+}
+
+
+Lights::~Lights()
+{
+    if (m_lightDevice) {
+        hw_device_t* device = (hw_device_t*) m_lightDevice;
+        device->close(device);
+    }
+}
+
+void Lights::setState(Lights::State newState)
+{
+    if (m_state != newState) {
+        if (newState == Lights::On) {
+            turnOn();
+        } else {
+            turnOff();
+        }
+    }
+}
+
+Lights::State Lights::state() const
+{
+    return m_state;
+}
+
+bool Lights::init()
+{
+    if (m_lightDevice) {
+        return true;
+    }
+
+    int err;
+    hw_module_t* module;
+
+    err = hw_get_module(LIGHTS_HARDWARE_MODULE_ID, (hw_module_t const**)&module);
+    if (err == 0) {
+        hw_device_t* device;
+        err = module->methods->open(module, LIGHT_ID_NOTIFICATIONS, &device);
+        if (err == 0) {
+            m_lightDevice = (light_device_t*)device;
+            return true;
+        } else {
+            qWarning() << "Failt to access notification lights";
+        }
+    } else {
+        qWarning() << "Failt to initialize lights hardware.";
+    }
+    return false;
+}
+
+void Lights::turnOn()
+{
+    if (!init()) {
+        qWarning() << "No lights device";
+        return;
+    }
+
+    if (m_state == Lights::On) {
+        return;
+    }
+
+    // pulse
+    light_state_t state;
+    memset(&state, 0, sizeof(light_state_t));
+    state.color = 0xff0000ff; // blue
+    state.flashMode = LIGHT_FLASH_TIMED;
+    state.flashOnMS = 1000;
+    state.flashOffMS = 1000;
+    state.brightnessMode = BRIGHTNESS_MODE_USER;
+
+    if (m_lightDevice->set_light(m_lightDevice, &state) != 0) {
+         qWarning() << "Fail to turn the light off";
+    } else {
+        m_state = Lights::On;
+        Q_EMIT stateChanged(m_state);
+    }
+}
+
+void Lights::turnOff()
+{
+    if (!init()) {
+        qWarning() << "No lights device";
+        return;
+    }
+
+    if (m_state == Lights::Off) {
+        return;
+    }
+
+    light_state_t state;
+    memset(&state, 0, sizeof(light_state_t));
+    state.color = 0x00000000;
+    state.flashMode = LIGHT_FLASH_NONE;
+    state.flashOnMS = 0;
+    state.flashOffMS = 0;
+    state.brightnessMode = 0;
+
+    if (m_lightDevice->set_light(m_lightDevice, &state) != 0) {
+        qWarning() << "Fail to turn the light off";
+    } else {
+        m_state = Lights::Off;
+        Q_EMIT stateChanged(m_state);
+    }
+}
+
+
+

=== added file 'plugins/Lights/Lights.h'
--- plugins/Lights/Lights.h	1970-01-01 00:00:00 +0000
+++ plugins/Lights/Lights.h	2014-06-27 20:48:38 +0000
@@ -0,0 +1,56 @@
+/*
+ * Copyright (C) 2014 Canonical, Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Author: Renato Araujo Oliveira Filho <renato.filho@canonical.com>
+ */
+
+#ifndef UNITY_LIGHTS_H
+#define UNITY_LIGHTS_H
+
+#include <QtCore/QObject>
+
+struct light_device_t;
+
+class Lights: public QObject
+{
+    Q_OBJECT
+    Q_ENUMS(State)
+    Q_PROPERTY(State state READ state  WRITE setState NOTIFY stateChanged)
+
+public:
+    enum State {
+        Off,
+        On,
+    };
+
+    explicit Lights(QObject *parent = 0);
+    ~Lights();
+
+    void setState(State newState);
+    State state() const;
+
+Q_SIGNALS:
+    void stateChanged(State newState);
+
+private:
+    State m_state;
+    light_device_t* m_lightDevice;
+
+    bool init();
+    void turnOff();
+    void turnOn();
+};
+
+#endif

=== added file 'plugins/Lights/plugin.cpp'
--- plugins/Lights/plugin.cpp	1970-01-01 00:00:00 +0000
+++ plugins/Lights/plugin.cpp	2014-06-27 20:48:38 +0000
@@ -0,0 +1,36 @@
+/*
+ * Copyright (C) 2012,2013 Canonical, Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Gerry Boland <gerry.boland@canonical.com>
+ *          Michael Terry <michael.terry@canonical.com>
+ */
+
+#include "plugin.h"
+#include "Lights.h"
+
+#include <QtQml/qqml.h>
+
+static QObject *lights_provider(QQmlEngine *engine, QJSEngine *scriptEngine)
+{
+    Q_UNUSED(engine)
+    Q_UNUSED(scriptEngine)
+    return new Lights();
+}
+
+void LightsPlugin::registerTypes(const char *uri)
+{
+    Q_ASSERT(uri == QLatin1String("Lights"));
+    qmlRegisterSingletonType<Lights>(uri, 0, 1, "Lights", lights_provider);
+}

=== added file 'plugins/Lights/plugin.h'
--- plugins/Lights/plugin.h	1970-01-01 00:00:00 +0000
+++ plugins/Lights/plugin.h	2014-06-27 20:48:38 +0000
@@ -0,0 +1,35 @@
+/*
+ * Copyright (C) 2012,2013 Canonical, Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors: Gerry Boland <gerry.boland@canonical.com>
+ *          Michael Terry <michael.terry@canonical.com>
+ */
+
+#ifndef LIGHTS_PLUGIN_H
+#define LIGHTS_PLUGIN_H
+
+#include <QtQml/QQmlEngine>
+#include <QtQml/QQmlExtensionPlugin>
+
+class LightsPlugin : public QQmlExtensionPlugin
+{
+    Q_OBJECT
+    Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
+
+public:
+    void registerTypes(const char *uri);
+};
+
+#endif

=== added file 'plugins/Lights/qmldir'
--- plugins/Lights/qmldir	1970-01-01 00:00:00 +0000
+++ plugins/Lights/qmldir	2014-06-27 20:48:38 +0000
@@ -0,0 +1,3 @@
+module Lights
+plugin Lights-qml
+typeinfo Lights.qmltypes

=== modified file 'qml/Panel/Indicators/DefaultIndicatorWidget.qml'
--- qml/Panel/Indicators/DefaultIndicatorWidget.qml	2013-12-12 09:55:17 +0000
+++ qml/Panel/Indicators/DefaultIndicatorWidget.qml	2014-06-27 20:48:38 +0000
@@ -32,6 +32,14 @@
     width: itemRow.width
     enabled: false
 
+    // WORKAROUND: For now we will enable led indicator support only for messaging indicator
+    // in the future we should export a led API insted of doing that,
+    Loader {
+        id: indicatorLed
+        // only load source Component if the icons contains the new message icon
+        source: (indicatorWidget.icons && (String(indicatorWidget.icons).indexOf("indicator-messages-new") != -1)) ? Qt.resolvedUrl("IndicatorsLight.qml") : ""
+    }
+
     Row {
         id: itemRow
         width: childrenRect.width

=== added file 'qml/Panel/Indicators/IndicatorsLight.qml'
--- qml/Panel/Indicators/IndicatorsLight.qml	1970-01-01 00:00:00 +0000
+++ qml/Panel/Indicators/IndicatorsLight.qml	2014-06-27 20:48:38 +0000
@@ -0,0 +1,38 @@
+/*
+ * Copyright 2014 Canonical Ltd.
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU Lesser General Public License as published by
+ * the Free Software Foundation; version 3.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
+ * Authors:
+ *      Renato Araujo Oliveira Filho <renato@canonical.com>
+ */
+
+import QtQuick 2.0
+import Powerd 0.1
+import Lights 0.1
+
+QtObject {
+    id: root
+
+    Component.onDestruction: Lights.state = Lights.Off
+
+    // QtObject does not have children
+    property var _connections: Connections {
+        id: powerConnection
+
+        target: Powerd
+        onDisplayPowerStateChange: {
+            Lights.state = (status === Powerd.Off) ? Lights.On : Lights.Off
+        }
+    }
+}

